#
# spec file for package fwupdate
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


Name:           fwupdate
Version:        0.5
Release:        5.3.1
Summary:        Tools to manage UEFI firmware updates
License:        GPL-2.0-or-later
Group:          System/Base
Url:            https://github.com/rhinstaller/fwupdate
Source:         https://github.com/rhinstaller/fwupdate/releases/download/0.5/%{name}-%{version}.tar.bz2
Patch0:         %{name}-suse-build.patch
Patch1:         %{name}-bsc988000-set-a-mode-with-efi_set_variable.patch
Patch2:         %{name}-fix-efivar-0.24-api.patch
Patch3:         %{name}-unset-immutable-flag.patch
Patch4:         %{name}-bsc988886-add-leading-space.patch
Patch5:         %{name}-bsc1113008-dont-add-headers-to-fmp-capsules.patch
Patch6:         %{name}-skip-fwupdate-verbose.patch
BuildRequires:  efivar-devel >= 0.21
BuildRequires:  elfutils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gnu-efi >= 3.0.2
BuildRequires:  pesign-obs-integration
BuildRequires:  pkg-config
BuildRequires:  popt-devel
BuildRequires:  systemd-rpm-macros
Requires:       %{name}-efi
Requires:       efibootmgr
Requires:       libfwup0 = %{version}-%{release}
Requires:       shim
%{?systemd_requires}
ExclusiveArch:  x86_64 %{ix86}

%if 0%{?is_opensuse}
%global efidir opensuse
%else
%global efidir sles
%endif

%description
fwupdate provides a simple command line interface to the UEFI firmware updates.

%package -n libfwup0
Summary:        Library to manage UEFI firmware updates
Group:          System/Libraries

%description -n libfwup0
Library to allow for the simple manipulation of UEFI firmware updates.

%package devel
Summary:        Development headers for libfwup
Group:          Development/Libraries/Other
Requires:       efivar-devel >= 0.21
Requires:       fwupdate = %{version}-%{release}
Requires:       libfwup0 = %{version}-%{release}

%description devel
development headers required to use libfwup.

%package efi
Summary:        UEFI binaries used by libfwup
Group:          System/Base
Requires:       shim

%description efi
UEFI binaries used by libfwup to update the firmware.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch1 -p1
if [ "$(pkg-config --modversion efivar)" > "0.23" ]; then
%patch2 -p1
fi
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

%build
make OPT_FLAGS="$RPM_OPT_FLAGS" libdir=%{_libdir} bindir=%{_bindir} \
     EFIDIR=%{efidir} GNUEFIDIR=%{_libdir} %{?_smp_mflags}

%install
export BRP_PESIGN_FILES='%{_libdir}/efi/fwup*.efi'
%make_install libdir=%{_libdir} bindir=%{_bindir} mandir=%{_mandir} \
              localedir=%{_datadir}/locale/ includedir=%{_includedir} \
	      libexecdir=%{_libexecdir} datadir=%{_datadir} EFIDIR=%{efidir}

echo 0%{?_build_create_debug}
%if 0%{?_build_create_debug} == 0
rm -rf %{buildroot}/usr/src/debug/%{name}*
rm -f  %{buildroot}/usr/lib/debug/%{_libdir}/efi/fwup*.efi.debug
%endif

%fdupes %{buildroot}%{_mandir}/*

# create rcsymlink
mkdir -p %{buildroot}%{_sbindir}
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcfwupdate-cleanup

%pre
%service_add_pre fwupdate-cleanup.service

%post
%service_add_post fwupdate-cleanup.service

%preun
%service_del_preun fwupdate-cleanup.service

%postun
%service_del_postun fwupdate-cleanup.service

%post -n libfwup0 -p /sbin/ldconfig

%postun -n libfwup0 -p /sbin/ldconfig

%posttrans -n %{name}-efi
# Create the directory for the firwmare update capsule
mkdir -p /boot/efi/EFI/%{efidir}/fw
# Install the UEFI firmware update program
cp %{_libdir}/efi/fwup*.efi /boot/efi/EFI/%{efidir}

%postun -n %{name}-efi
if [ "$1" = 0 ] ; then
	# Remove all the capsules
	rm -rf /boot/efi/EFI/%{efidir}/fw
	# Remove the UEFI firmware update program
	rm -f /boot/efi/EFI/%{efidir}/fwup*.efi
fi

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/fwupdate
%doc %{_mandir}/man1/*
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/fwupdate
%{_unitdir}/fwupdate-cleanup.service
%ghost %attr(0755,root,root) %dir %{_rundir}/fwupdate/
%attr(0755,root,root) %dir %{_libexecdir}/fwupdate/
%{_libexecdir}/fwupdate/cleanup
%{_sbindir}/rcfwupdate-cleanup

%files devel
%defattr(-,root,root)
%doc %{_mandir}/man3/*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n libfwup0
%defattr(-,root,root)
%{_libdir}/*.so.*

%files efi
%defattr(-,root,root)
%dir %{_libdir}/efi
%{_libdir}/efi/fwup*.efi

%changelog
* Wed Oct 31 2018 glin@suse.com
- Add fwupdate-bsc1113008-dont-add-headers-to-fmp-capsules.patch
  to avoid adding headers to FMP capsules (bsc#1113008)
- Add fwupdate-skip-fwupdate-verbose.patch to keep the debug
  variable
- Amend the spec file to avoid fwup*.efi from being removed
  mistakenly (bsc#1112832)
* Thu Mar 30 2017 glin@suse.com
- Remove the debug source and info of the EFI files when disabling
  the debug build (bsc#1031554)
  + Also remove the efi-debuginfo subpackage since the debug file
    is packaged correctly now.
* Thu Mar  9 2017 rw@suse.com
- Enable efivar API patch based on pkg-config data and require
  at least gnu-efi-3.0.2.  (ramification of FATE#322108)
* Thu Jul 28 2016 glin@suse.com
- Relax the requirement of efivar-devel and disable the efivar API
  patch for openSUSE Leap 42.x and SLE
* Thu Jul 21 2016 glin@suse.com
- Amend the spec file to detect SLE/openSUSE (bsc#990228)
* Fri Jul 15 2016 glin@suse.com
- Add fwupdate-fix-efivar-0.24-api.patch to fix the compilation
  errors due to the change of efivar APIs
- Bump BuildRequires of efivar-devel to 0.24
- Add fwupdate-unset-immutable-flag.patch to unset the immutable
  flag before clean the EFI variables (bsc#964726)
- Amend fwupdate-suse-build.patch (FATE#319345)
  + omit the build-id and package fwudpate-efi-debuginfo in a less
    hacky way.
  + Use the RPM_OPT_FLAGS for the user space programs
- Add fwupdate-bsc988886-add-leading-space.patch to add the leading
  space to the load option (bsc#988886)
* Thu Jul  7 2016 glin@suse.com
- Correct the EFI dir for SLE-12-SP2 (FATE#319345)
- Install fwup*.efi to the EFI system partition (FATE#319345)
- Add fwupdate-bsc988000-set-a-mode-with-efi_set_variable.patch to
  fix the file mode (bsc#988000)
* Sun May  8 2016 jengelh@inai.de
- Drop unnecessary specfile elements.
  fwupdate seems not required for libfwup, remove the requirement.
- Correct requires of fwupdate-devel
- Use source URLs
* Fri May  6 2016 coolo@suse.com
- own bash-completion directory as no longer provided by
  util-linux (boo#977259)
* Mon Mar 28 2016 glin@suse.com
- Add the missing Group
* Wed Mar  2 2016 glin@suse.com
- initial import 0.5 (FATE#319345)
- Add fwupdate-suse-build.patch to change the destination of the
  EFI files and remove the po files
